pub struct FolderSyncReducerAsync<Item, F, S, Final> { /* private fields */ }Trait Implementations
Sourceimpl<Item, F> Sink<Item> for FolderSyncReducerAsync<Item, F, F::State, Final>where
F: FolderSync<Item>,
impl<Item, F> Sink<Item> for FolderSyncReducerAsync<Item, F, F::State, Final>where
F: FolderSync<Item>,
type Done = <F as FolderSync<Item>>::Done
Sourcefn poll_forward(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
stream: Pin<&mut impl Stream<Item = Item>>,
) -> Poll<Self::Done>
fn poll_forward( self: Pin<&mut Self>, cx: &mut Context<'_>, stream: Pin<&mut impl Stream<Item = Item>>, ) -> Poll<Self::Done>
Returns
Poll::Ready when a) it can’t accept any more elements from stream and b) all
accepted elements have been fully processed. By convention, stream yielding None
typically triggers (a).fn send(&mut self, item: Item) -> Send<'_, Self, Item> ⓘwhere
Self: Unpin,
fn send_all<'a, S>(&'a mut self, items: &'a mut S) -> SendAll<'a, Self, S> ⓘ
fn done(&mut self) -> Done<'_, Self, Item> ⓘwhere
Self: Unpin,
Sourceimpl<Item, F> Sink<Item> for FolderSyncReducerAsync<Item, F, F::State, Inter>where
F: FolderSync<Item>,
impl<Item, F> Sink<Item> for FolderSyncReducerAsync<Item, F, F::State, Inter>where
F: FolderSync<Item>,
type Done = <F as FolderSync<Item>>::State
Sourcefn poll_forward(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
stream: Pin<&mut impl Stream<Item = Item>>,
) -> Poll<Self::Done>
fn poll_forward( self: Pin<&mut Self>, cx: &mut Context<'_>, stream: Pin<&mut impl Stream<Item = Item>>, ) -> Poll<Self::Done>
Returns
Poll::Ready when a) it can’t accept any more elements from stream and b) all
accepted elements have been fully processed. By convention, stream yielding None
typically triggers (a).fn send(&mut self, item: Item) -> Send<'_, Self, Item> ⓘwhere
Self: Unpin,
fn send_all<'a, S>(&'a mut self, items: &'a mut S) -> SendAll<'a, Self, S> ⓘ
fn done(&mut self) -> Done<'_, Self, Item> ⓘwhere
Self: Unpin,
impl<'pin, Item, F, S, Final> Unpin for FolderSyncReducerAsync<Item, F, S, Final>where
__FolderSyncReducerAsync<'pin, Item, F, S, Final>: Unpin,
impl<Item, F, S, Final> UnsafeUnpin for FolderSyncReducerAsync<Item, F, S, Final>