pub struct ReduceC7Async<A, B, C, D, E, F, G, S0, S1, S2, S3, S4, S5, S6>{ /* private fields */ }Trait Implementations
Sourceimpl<A: Sink<S0>, B: Sink<S1>, C: Sink<S2>, D: Sink<S3>, E: Sink<S4>, F: Sink<S5>, G: Sink<S6>, S0, S1, S2, S3, S4, S5, S6> Sink<(S0, S1, S2, S3, S4, S5, S6)> for ReduceC7Async<A, B, C, D, E, F, G, S0, S1, S2, S3, S4, S5, S6>
impl<A: Sink<S0>, B: Sink<S1>, C: Sink<S2>, D: Sink<S3>, E: Sink<S4>, F: Sink<S5>, G: Sink<S6>, S0, S1, S2, S3, S4, S5, S6> Sink<(S0, S1, S2, S3, S4, S5, S6)> for ReduceC7Async<A, B, C, D, E, F, G, S0, S1, S2, S3, S4, S5, S6>
type Done = (<A as Sink<S0>>::Done, <B as Sink<S1>>::Done, <C as Sink<S2>>::Done, <D as Sink<S3>>::Done, <E as Sink<S4>>::Done, <F as Sink<S5>>::Done, <G as Sink<S6>>::Done)
Sourcefn poll_forward(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
stream: Pin<&mut impl Stream<Item = (S0, S1, S2, S3, S4, S5, S6)>>,
) -> Poll<Self::Done>
fn poll_forward( self: Pin<&mut Self>, cx: &mut Context<'_>, stream: Pin<&mut impl Stream<Item = (S0, S1, S2, S3, S4, S5, S6)>>, ) -> Poll<Self::Done>
Returns
Poll::Ready when a) it can’t accept any more elements from stream and b) all
accepted elements have been fully processed. By convention, stream yielding None
typically triggers (a).fn send(&mut self, item: Item) -> Send<'_, Self, Item> ⓘwhere
Self: Unpin,
fn send_all<'a, S>(&'a mut self, items: &'a mut S) -> SendAll<'a, Self, S> ⓘ
fn done(&mut self) -> Done<'_, Self, Item> ⓘwhere
Self: Unpin,
impl<'pin, A, B, C, D, E, F, G, S0, S1, S2, S3, S4, S5, S6> Unpin for ReduceC7Async<A, B, C, D, E, F, G, S0, S1, S2, S3, S4, S5, S6>
impl<A, B, C, D, E, F, G, S0, S1, S2, S3, S4, S5, S6> UnsafeUnpin for ReduceC7Async<A, B, C, D, E, F, G, S0, S1, S2, S3, S4, S5, S6>